///////////////////////////////////////////////////////////////////////////////
//
// John's No-ADS proxy auto configuration script
//	http://www.schooner.com/~loverso/no-ads/
//	loverso@schooner.com
//
// Copyright 1996-2002, John LoVerso.  All Rights Reserved.
//
//	Permission is given to use and distribute this file, as long as this
//	copyright message and author notice are not removed.
//
//	No responsibility is taken for any errors on inaccuracies inherent
//	either to the comments or the code of this program, but if reported
//	to me, then an attempt will be made to fix them.
//
// ("no monies exchanged" in Copyright clause removed 11/2001)
//
// $Id: no-ads.pac,v 3.27 2002/07/08 21:40:35 loverso Exp $
//

///////////////////////////////////////////////////////////////////////////////
//
// This simple kludge uses a mechanism built into most browsers (IE,
// Netscape, and Mozilla) on most platforms to block connections to
// banner ad servers.
//
// This mechanism uses the "proxy auto configuration" to blackhole requests
// to load ad images without forcing all your traffic through an ad-blocking
// proxy server.  Of course, unlike ad-blocking proxy servers, this does not
// otherwise not strip cookies.
//
// "Proxy auto configuration" invokes the JavaScript FindProxyForURL function
// below each time your browser requests a URL.  This works even if you have
// JavaScript otherwise disabled in your browser!  (Which you should!)
//

//
// Send me your additions or comments.  I'll credit you in the file.
// (But I've removed all email addresses to stop spam harvesters).
//


///////////////////////////////////////////////////////////////////////////////
//
// These are the basic steps needed to use "no-ads.pac".
// Detailed instructions follow below!
//
// 1. Save this as a file (no-ads.pac) on your local disk
//    (or, add it to your home page, if you have one)
// 2. Select a no-ads "blackhole".
// 3. Configure your browser to use this file as it's auto proxy configuration.
// 4. Clear your browser's cache
//    (or else it may still show you ads it has saved on your disk).
//


///////////////////////////////////////////////////////////////////////////////
//
// 1. SAVE THIS FILE
//
// Copy this file to your local machine; use your home directory (UNIX)
// or your Desktop or C:\ directory (Windows).
//



///////////////////////////////////////////////////////////////////////////////
//
// 2. SELECT A NO-ADS BLACKHOLE
//
// If you are using Internet Explorer, you are all set.  Skip this step.
//
//
// The basic trick is to match the site or URL of annoying web content and
// tell the browser to use a proxy that will deny loading of that resource
// (image, page, etc).
//
// A "Blackhole" proxy server is one that always denies loading a web page.
// ("send it off to a blackhole").
//
// When you initially get "no-ads.pac", it is using this as the bloakhole:
//
//	return "PROXY localhost:3421";
//
// This says to use the local host at a port which nothing should be listening
// on.  Thus, this is "a server that doesn't repond."
//
//
// Some possibilities for the blackhole:
//
//	a. A server that doesn't respond.
//
//		If you do nothing, then this is configured to direct annoying
//		content to the proxy running on your localhost at port 3421.
//		Since you shouldn't have anything running on that port, that
//		connection will timeout and the annoying content will never be
//		loaded.
//
//		THIS ONLY WORKS FOR Internet Explorer!
//
//		Netscape waits for the proxy server to connect (usually it
//		needs to load part of the image to layout the web page), and
//		then asks if you want to disable the proxy that won't answer.
//		Mozilla will given alert saying it couldn't connect to the
//		image server.
//
//		IE doesn't care that the proxy server isn't responding.  As
//		this avoids a connection for annoying content, it is fastest.
//
//	b. A simple, blackhole server
//
//		When needed, I run a simple "server" at port 3421 that denies
//		all requests.  I include the shell script I use; this could
//		also be done with a "wait"-style perl script that did the same
//		thing, if exec'ing a shell was overly expensive on your computer
//		(it isn't on mine).
//
//		Add this to inetd.conf: ("bmap" is the defined server on port
//		3421)
//
//		    bmap stream tcp nowait nobody /usr/local/lib/noproxy noproxy
//
//		Create /usr/local/lib/noproxy as this shell script:
//
//		#!/bin/sh
//		read a
//		read b
//		echo HTTP/1.0 501 No Ads Accepted
//		echo ""
//		exit
//
//		Note: This little script doesn't work on Linux because of
//		      (IMHO) broken way it's TCP stack works.  I have a fix;
//		      I'll add to my web page when I get a chance.
//
//	c. A trick: use an HTTP/1.0 non-proxy server
//
//		An HTTP/1.0 non-proxy server will return a 501 error when
//		given a proxy request!  If you So, you can just return as the
//		PROXY your local intranet web server!  However, it will likely
//		also log error, wasting a tad bit of resources.
//
//	***
//	*** Be sure to update the "PROXY" line below with the correct
//	*** hostname:port of your blackhole server!!
//	***
//
//	***
//	*** If you already use a proxy server to access the WWW,
//	*** change the "DIRECT" line below to your proxy server.
//	***


///////////////////////////////////////////////////////////////////////////////
//
// 3. TO CONFIGURE YOUR BROWSER
//
// The Proxy Auto Configuration file can be either on the local disk or
// accessed from a web server, with the following constraints:
//
//	a. IE4 can only load the PAC from a web server (http:// URL)
//	b. Netscape, Mozilla, and IE 5can load the PAC from anywhere.
//	c. Netscape and Mozilla require the correct MIME type when loading
//	   the PAC from a web server.
//
//
// To set the Proxy Auto Configuration with Netscape Navigator or Mozilla:
//
//   1. Enable Proxy Auto Config:
//
//	Open "Edit->Preferences"
//	Select "Advanced"
//	Select "Proxies"
//	Select "Auto proxy configuration" option
//	Enter URL or path of this file
//
//		http://yourserver/no-ads.pac
//
//	If you place this on your local disk, you should use a
//	file: URL such as:
//
//		file:/home/loverso/no-ads.pac			(UNIX)
//		file://c:/windows/desktop/no-ads.pac		(Windows)
//
//   2. If you are serving this from a web server, Netscape Navigator requires
//      correct MIME type on the file before using it.  You must configure
//      your web server to provide a "application/x-ns-proxy-autoconfig"
//	MIME type.
//
//      a. For Apache, name the file with a ".pac" extension and add this
//	   line to the http.conf (or the .htaccess file in the same directory):
//
//		AddType application/x-ns-proxy-autoconfig .pac
//
//      b. For IIS (instructions from Kevin Roth)
//
//	   Open Internet Services Manager
//	   Right click on the web site (or directory) you wish to change.
//	   Choose Properties
//	   Click the "HTTP Headers" tab
//	   Click the "File Types" button in the "MIME Map" section
//	   Click the "New Type..." button
//	   Enter "pac" for "Associated Extension"
//	   Enter "application/x-ns-proxy-autoconfig" for "Content Type (MIME)"
//	   Click OK to close the Add type dialog, the MIME types dialog,
//		and the main properties dialog.
//
//      (This is definately needed for NS, but not for IE)
//
//
// To set the Proxy Auto Configuration with IE:
//
//   1. Enable Proxy Auto Config:
//
//	Open "Tools->Internet Options"
//	Select "Connections" tab
//	Click "LAN Settings"
//		or Choose an entry from "Dial-up settings" and click "Settings"
//
//	On the settings dialog, select "Use automatic configuration script"
//	Enter the URL of this file in Address field.
//
//		http://yourserver/no-ads.pac
//		file://c:/windows/desktop/no-ads.pac		(Windows)
//
//	You can only use a file: URL with IE5 (or later).
//	(I have tested using "file:" with 5.0sp2/Win98 and 5.5sp2/Win2k).
//
//   2. Fix Security Settings (IMPORTANT):
//
//	Select "Security" tab
//	Select "Local intranet"
//	Click "Sites" box
//	Unselect "include all sites that bypass the proxy server" option
//
//   3. Disable "Auto Proxy Caching" (IMPORTANT):
//      (thanks to Kevin Roth for alerting me of this!)
//
//	IE contains a proxy caching mechanism that will defeat the ability
//	to block ad servers that share content with non-ads.  To prevent this,
//	add the registry key described in this MS KB article:
//
//		http://support.microsoft.com/support/kb/articles/Q271/3/61.ASP
//
//	To make it easy, download this file and load it into the registry:
//      (Updated 2001-1-31)
//		http://www.schooner.com/~loverso/no-ads/no-auto-proxy-cache.reg
//
//   IE doesn't currently check the MIME type of the loaded file.
//
//   To see some notes from MS on PAC in IE, see
//	http://msdn.microsoft.com/library/periodic/period99/faq0599.htm
//


///////////////////////////////////////////////////////////////////////////////
//
// 4. CLEAR YOUR BROWSER'S CACHE
//
// For Internet Explorer:
//
//	Open "Tools->Internet Options"
//	Select "Delete Files" under "Temporary Internet Files"
//	Click "OK"
//
// For Mozilla/Netscape Navigator:
//
//	Open "Edit->Preferences"
//	Select "Advanced"
//	Select "Proxies"
//	Click "Clear Disk Cache"
//	Click "Clear Memory Cache"


///////////////////////////////////////////////////////////////////////////////
//
// To see the definition of this page's JavaScript contents, see
//
//	http://home.netscape.com/eng/mozilla/2.0/relnotes/demo/proxy-live.html
//
// Microsoft includes this in thie KB article:
//	http://support.microsoft.com/support/kb/articles/Q209/2/66.ASP
//
// Special PAC functions:
// Hostname:
//	isPlainHostName(host)
//	dnsDomainIs(host, domain)
//	localHostOrDomainIs(host, hostdom)
//	isResolvable(host)
//	isInNet(host, pattern, mask)
// Utility:
//	dnsResolve(host)
//	myIpAddress()
//	dnsDomainLevels(host)
// URL:
//	shExpMatch(str, shexp)
// Time:
//	weekdayRange(wd1, wd2, gmt)
//	dateRange(...)
//	timeRange(...)
//
// Other methods:
//	alert(), etc
//	http://developer.netscape.com/docs/manuals/communicator/jsref/win1.htm
//


function FindProxyForURL(url, host)
{
    // debug
    // alert("checking: " + url);

    // Suggestion from Quinten Martens
    // Make everything lower case.
    url = url.toLowerCase();
    host = host.toLowerCase();

    // To add more sites, simply include them in the correct list in the
    // correct format.

    // The sites below are ones I currently block.  Tell me of others you add!

    if (0
	// Block IE4/5 "favicon.ico" fetches
	// (to avoid being tracked as having bookmarked the site)
	//
	// NOTE: IE5 *sometimes* fetches facicon.ico w/o using the proxy!
	|| shExpMatch(url, "*/favicon.ico")

	//////
	//
	// Global Section
	// tries to match common names
	//

	// Uncomment these if you want to really knock out ads.  After doing
	// so, you can probably remove rules below that mention ads or Ads.
	// || shExpMatch(url, "*ads*")

	// More targeted than the above
	|| (shExpMatch(url,"*/ads/*")
		// avoid false positives
		// http://www.coopercockpit.com/ads
		&& !dnsDomainIs(host, ".coopercockpit.com")
		// www.priceworld.com/Ads/SundayAds_sub.asp
	        && !(dnsDomainIs(host, ".priceworld.com") ||
			dnsDomainIs(host, ".intertraq.com"))
	    )

	// Some people remove the directories from the following rules
	// (i.e., they use "*banners" rather than "*/banners/*).
	// I think that allows too many false positives, so the rules
	// aren't that way by default.
	//
	|| shExpMatch(url,"*/banner/*")
	|| shExpMatch(url,"*/banners/*")
	|| shExpMatch(url,"*/banner_*")
	|| shExpMatch(url,"*/*_banner*")
	|| shExpMatch(url,"*/popunder/*")
	|| shExpMatch(url,"*/popunders/*")
	|| shExpMatch(url,"*/popup/*")
	|| shExpMatch(url,"*/popups/*")
	|| shExpMatch(url,"*/ad/*")

	// This removes all hostnames starting with "ad????."
	// (matches things like ad., ads., ads03., etc), but not others
	// (such as add.yahoo.com)  Modified with suggestion from Kevin Roth.
///	|| (shExpMatch(url, "http://ad*") &&
///	    !(   shExpMatch(url, "http://add*")
///	      || shExpMatch(url, "http://admin*")
///	      || shExpMatch(url, "http://advogato*")))

	|| (shExpMatch(host, "ad*")
	    && (
	        shExpMatch(host, "ad.*")
	     || shExpMatch(host, "ad?.*")
	     || shExpMatch(host, "ad??.*")
	     || shExpMatch(host, "ad???.*")
	     || shExpMatch(host, "ads???.*")
	   ) && !(
	        shExpMatch(host, "add*")
	     || shExpMatch(host, "admin*")
	   )
	)

///	|| ( ( shExpMatch(host,"ad.*")
///	       || shExpMatch(host,"ad?.*")
///	       || shExpMatch(host,"ad??.*")
///	       || shExpMatch(host,"ad???.*")
///	       || shExpMatch(host,"ads???.*")
///	     ) && !(
///	       shExpMatch(host,"add*")
///	     )
///	   )

	// Match hostnames
	|| shExpMatch(host, "*banner*")
	|| shExpMatch(host, "*adserv*")

	// or any subdomain "ads"
	|| (dnsDomainLevels(host) > 2 &&
	    shExpMatch(host, "*.ads.*"))


	//////
	//
	// banner/ad organizations
	// Just delete the entire namespace
	//

	// these set cookies
	|| dnsDomainIs(host, ".doubleclick.com")
        || dnsDomainIs(host, ".doubleclick.net")
	|| dnsDomainIs(host, ".globaltrack.com")
	|| dnsDomainIs(host, ".burstnet.com")
	|| dnsDomainIs(host, ".adbureau.net")
	|| dnsDomainIs(host, ".targetnet.com")
	|| dnsDomainIs(host, ".humanclick.com")
	|| dnsDomainIs(host, ".fastclick.com")
	|| dnsDomainIs(host, ".fastclick.net")
	|| dnsDomainIs(host, ".linkexchange.com")

	// these use 1x1 images to track you
	|| dnsDomainIs(host, ".admonitor.com")
	|| dnsDomainIs(host, ".focalink.com")

	|| dnsDomainIs(host, ".websponsors.com")
	|| dnsDomainIs(host, ".commission-junction.com")
	|| dnsDomainIs(host, ".advertising.com")
	|| dnsDomainIs(host, ".cybereps.com")
	|| dnsDomainIs(host, ".postmasterdirect.com")
	|| dnsDomainIs(host, ".advertising.com")
	|| dnsDomainIs(host, ".mediaplex.com")
	|| dnsDomainIs(host, ".adtegrity.com")
	|| dnsDomainIs(host, ".bannerbank.ru")
	|| dnsDomainIs(host, ".bannerspace.com")
	|| dnsDomainIs(host, ".theadstop.com")
	|| dnsDomainIs(host, ".l90.com")
	|| dnsDomainIs(host, ".webconnect.net")
	|| dnsDomainIs(host, ".avenuea.com")
	|| dnsDomainIs(host, ".flycast.com")
	|| dnsDomainIs(host, ".engage.com")
	|| dnsDomainIs(host, ".imgis.com")
	|| dnsDomainIs(host, ".datais.com")
	|| dnsDomainIs(host, ".link4ads.com")
	|| dnsDomainIs(host, ".247media.com")
	|| dnsDomainIs(host, ".hightrafficads.com")
	|| dnsDomainIs(host, ".qkimg.net")
	|| dnsDomainIs(host, ".tribalfusion.com")
	|| dnsDomainIs(host, ".rightserve.net")
	|| dnsDomainIs(host, ".admaximize.com")
	|| dnsDomainIs(host, ".valueclick.com")
	|| dnsDomainIs(host, ".adlibris.se")
	|| dnsDomainIs(host, ".vibrantmedia.com")
	|| dnsDomainIs(host, ".coremetrics.com")
	|| dnsDomainIs(host, ".vx2.cc")
	|| dnsDomainIs(host, ".webpower.com")
	|| dnsDomainIs(host, ".everyone.net")
	|| dnsDomainIs(host, ".zedo.com")
	|| dnsDomainIs(host, ".bigbangmedia.com")
	|| dnsDomainIs(host, ".ad-annex.com")
	|| dnsDomainIs(host, ".iwdirect.com")
	|| dnsDomainIs(host, ".adlink.de")
	|| dnsDomainIs(host, ".bidclix.net")
	|| dnsDomainIs(host, ".webclients.net")

	// */adv/*
	|| dnsDomainIs(host, ".bluestreak.com")

	// Virtumundo -- as annoying as they get
	|| dnsDomainIs(host, ".virtumundo.com")
	|| dnsDomainIs(host, ".treeloot.com")
	|| dnsDomainIs(host, ".memberprize.com")

	// internetfuel and _some_ of the sites they redirect to
	// (more internetfuel - from Sam G)
	|| dnsDomainIs(host, ".internetfuel.net")
	|| dnsDomainIs(host, ".internetfuel.com")
	|| dnsDomainIs(host, ".peoplecaster.com")
	|| dnsDomainIs(host, ".cupidsdatabase.com")
	|| dnsDomainIs(host, ".automotive-times.com")
	|| dnsDomainIs(host, ".healthy-lifetimes.com")
	|| dnsDomainIs(host, ".us-world-business.com")
	|| dnsDomainIs(host, ".internet-2-web.com")
	|| dnsDomainIs(host, ".my-job-careers.com")
	|| dnsDomainIs(host, ".freeonline.com")
	|| dnsDomainIs(host, ".exitfuel.com")
	|| dnsDomainIs(host, ".netbroadcaster.com")
	|| dnsDomainIs(host, ".spaceports.com")
	|| dnsDomainIs(host, ".mircx.com")
	|| dnsDomainIs(host, ".exitchat.com")
	|| dnsDomainIs(host, ".atdmt.com")

	//////
	//
	// banner servers
	// (typically these set cookies or serve animated ads)
	//

	|| dnsDomainIs(host, "commonwealth.riddler.com")
	|| dnsDomainIs(host, "banner.freeservers.com")
	|| dnsDomainIs(host, "usads.futurenet.com")
	|| dnsDomainIs(host, "banners.egroups.com")
	|| dnsDomainIs(host, "ngadclient.hearme.com")
	|| dnsDomainIs(host, "affiliates.allposters.com")
	|| dnsDomainIs(host, "adincl.go2net.com")
	|| dnsDomainIs(host, "webads.bizservers.com")

	// AOL
	|| dnsDomainIs(host, ".atwola.com")

/// matched by global rules
///	|| shExpMatch(url, "*freewebsites.com/banner/*")
///	|| shExpMatch(url, "*linkexchange.com/*banner*")
///	|| dnsDomainIs(host, "ad.linkexchange.com")
///	|| dnsDomainIs(host, "ads.infi.net")
///	|| dnsDomainIs(host, "adclub.net")
///	|| dnsDomainIs(host, "adserv.newcentury.net")
///	|| dnsDomainIs(host, "ad.adsmart.net")
///	|| dnsDomainIs(host, "adbot.com")
///	|| dnsDomainIs(host, "ads.softbank.net")
///	|| dnsDomainIs(host, "ad.preferences.com")
///	|| dnsDomainIs(host, "ads.jwtt3.com")
///	|| dnsDomainIs(host, "ads.ugo.com")
///	|| dnsDomainIs(host, "ads.csi.com")
///	|| dnsDomainIs(host, "ads.enliven.com")
///	|| dnsDomainIs(host, "adcontent.gamespy.com")
///	|| dnsDomainIs(host, "adrunner.mycomputer.com")

///	|| shExpMatch(url, "*.computers.com/Ads*")
///	|| shExpMatch(url, "*.cnet.com/Ads*")
///	|| shExpMatch(url, "*/cnet*/Ads*")

///	|| shExpMatch(url, "*socialnet.com/banners*")
///	|| shExpMatch(url, "*adex*.flycast.com/*")
///	|| shExpMatch(url, "*ads*.sandpiper.com/*")

///	|| dnsDomainIs(host, "ads.bla-bla.com")

	//////
	//
	// popups/unders
	//

	|| dnsDomainIs(host, "remotead.cnet.com")
	|| dnsDomainIs(host, ".1st-dating.com")
	|| dnsDomainIs(host, ".mousebucks.com")
	|| dnsDomainIs(host, ".yourfreedvds.com")
	|| dnsDomainIs(host, ".popupsavings.com")
	|| dnsDomainIs(host, ".popupmoney.com")
	|| dnsDomainIs(host, ".popuptraffic.com")
	|| dnsDomainIs(host, ".popupnation.com")
	|| dnsDomainIs(host, ".infostart.com")
	|| dnsDomainIs(host, ".popupad.net")
	|| dnsDomainIs(host, ".usapromotravel.com")
	|| dnsDomainIs(host, ".goclick.com")
	|| dnsDomainIs(host, ".trafficwave.net")
	|| dnsDomainIs(host, ".popupad.net")

	// Popups from ezboard
	|| dnsDomainIs(host, ".greenreaper.com")
	|| dnsDomainIs(host, ".spewey.com")
	|| dnsDomainIs(host, ".englishharbour.com")
	|| dnsDomainIs(host, ".casino-trade.com")
	|| dnsDomainIs(host, "got2goshop.com")
	// more ezboard crud (from Miika Asunta)
	|| dnsDomainIs(host, ".addynamix.com")
	|| dnsDomainIs(host, ".trafficmp.com")
	|| dnsDomainIs(host, ".makingmoneyfromhome.net")
	|| dnsDomainIs(host, ".leadcart.com")

	// http://www.power-mark.com/js/popunder.js
	|| dnsDomainIs(host, ".power-mark.com")

	// handled by */popunder/* above
	// http://www.tripod.lycos.com/popunder/tripod_popunder.html

	//////
	//
	// User tracking (worse than ads) && hit counting "services"
	//

	// "web trends live"
	|| dnsDomainIs(host, "webtrendslive.com")
	|| dnsDomainIs(host, ".wtlive.com")

	// 1x1 tracking images
	// ** (but also used in some pay-for-clicks that I want to follow,
	// **  so disabled for now.  9/2001)
	// || dnsDomainIs(host, "service.bfast.com")

	// one whole class C full of ad servers
	|| isInNet(host, "66.40.16.0", "255.255.255.0")

	|| dnsDomainIs(host, ".web-stat.com")
	|| dnsDomainIs(host, ".superstats.com")
	|| dnsDomainIs(host, ".allhits.ru")
	|| dnsDomainIs(host, ".list.ru")
	|| dnsDomainIs(host, ".counted.com")
	|| dnsDomainIs(host, ".rankyou.com")
	|| dnsDomainIs(host, ".clickcash.com")
	|| dnsDomainIs(host, ".clickbank.com")
	|| dnsDomainIs(host, ".paycounter.com")
	|| dnsDomainIs(host, ".cashcount.com")
	|| dnsDomainIs(host, ".clickedyclick.com")
	|| dnsDomainIs(host, ".clickxchange.com")
	|| dnsDomainIs(host, ".sitestats.com")
	|| dnsDomainIs(host, ".site-stats.com")
	|| dnsDomainIs(host, ".hitbox.com")
	|| dnsDomainIs(host, ".exitdirect.com")
	|| dnsDomainIs(host, ".realtracker.com")
	|| dnsDomainIs(host, ".etracking.com")
	|| dnsDomainIs(host, ".livestat.com")
	|| dnsDomainIs(host, ".spylog.com")
	|| dnsDomainIs(host, ".freestats.com")
	|| dnsDomainIs(host, ".addfreestats.com")
	|| dnsDomainIs(host, ".addfreestats.com")
	|| dnsDomainIs(host, ".topclicks.net")
	|| dnsDomainIs(host, ".mystat.pl")
	|| dnsDomainIs(host, ".hitz4you.de")

	//////
	//
	// "Surveys"
	//

	|| dnsDomainIs(host, ".zoomerang.com")

	//////
	//
	// "Casino" ads (scams)
	//

	|| dnsDomainIs(host, ".aceshigh.com")
	|| dnsDomainIs(host, ".idealcasino.net")
	|| dnsDomainIs(host, ".casinobar.net")
	|| dnsDomainIs(host, ".casinoionair.com")

	|| (dnsDomainIs(host, ".go2net.com") &&
		shExpMatch(url, "*adclick*"))

	//////
	//
	// Directed at extra annoying places
	//

	// Attempts to download ad-supported spyware without asking first
	|| dnsDomainIs(host, ".gator.com")

	// Bravenet & Ezboard
	|| (dnsDomainIs(host, ".ezboard.com") &&
		shExpMatch(url, "*/bravenet/*"))
	|| (dnsDomainIs(host, ".bravenet.com") && (
			   shExpMatch(host, "*counter*"))
			|| shExpMatch(url, "*/jsbanner*")
	)

	// GeoCities
	// (checking "toto" from Prakash Persaud)
	|| ((  dnsDomainIs(host,"geo.yahoo.com")
	    || dnsDomainIs(host,".geocities.com")) && (
		   shExpMatch(url,"*/toto?s*")
		|| shExpMatch(url, "*geocities.com/js_source*")
		|| dnsDomainIs(host, "visit.geocities.com")
	    )
	)

	// Yahoo ads via Akamai
	// http://us.a1.yimg.com/us.yimg.com/a/...
	|| (dnsDomainIs(host,"yimg.com") &&
		shExpMatch(url,"*yimg.com/a/*"))

	// FortuneCity - ads and tracking
	|| (dnsDomainIs(host,".fortunecity.com") &&
		(shExpMatch(url,"*/js/adscript*")
		 || shExpMatch(url,"*/js/fctrack*")))

	// zdnet
	|| (dnsDomainIs(host, ".zdnet.com") &&
		(dnsDomainIs(host, "ads3.zdnet.com")
		 || shExpMatch(url, "*/texis/cs/ad.html")
		 || shExpMatch(url, "*/adverts")))

	// Be Free affiliate ads
	|| dnsDomainIs(host, ".reporting.net")
	|| dnsDomainIs(host, ".affliate.net")
	|| (dnsDomainIs(host, ".akamai.net") &&
		 shExpMatch(url, "*.affiliate.net/*"))

	// Infospace.com popunder
	// for "webmarket.com" & "shopping.dogpile.com" -- just say no!
	|| (dnsDomainIs(host, ".infospace.com") &&
		shExpMatch(url, "*/goshopping/*"))
	|| dnsDomainIs(host, ".webmarket.com")
	|| dnsDomainIs(host, "shopping.dogpile.com")

	// goto.com popunder for information.gopher.com
	|| dnsDomainIs(host, "information.gopher.com")

	// About.com popunder
	|| (dnsDomainIs(host, ".about.com") &&
		shExpMatch(url, "*/sprinks/*"))

	// Dell
	|| (dnsDomainIs(host, ".dell.com") &&
		shExpMatch(url, "*/images/affiliates/*"))

/// matched by global rules
///	// intellicast
///	|| (dnsDomainIs(host, ".intellicast.com") &&
///		 shExpMatch(url, "*images/ads/*"))

	// tomshardware
	// they are most annoying:
	// - cookies on their background images to track you
	// - looping shockwave ads
	// this kills most of the crud
	|| ((dnsDomainIs(host, ".tomshardware.com") ||
		isInNet(host, "216.92.21.0", "255.255.255.0"))
	    && (
	        shExpMatch(url, "*/cgi-bin/banner*")
	        || shExpMatch(url, "*/cgi-bin/bd.m*")
	        || shExpMatch(url, "*/images/banner/*")
	    )
	)

/// matched by global rules
///	// these set cookies
///	|| shExpMatch(url, "*.dejanews.com/ads*")
///	|| shExpMatch(url, "*.deja.com/ads*")
	|| shExpMatch(url, "*MapsOnUs.com/ad.images*")

	// Slashdot: added these when I saw hidden 1x1 images with cookies
	|| dnsDomainIs(host, "adfu.blockstackers.com")
	|| (dnsDomainIs(host, "slashdot.org")
	    && (
	           shExpMatch(url, "*/slashdot/pc.gif*")
		|| shExpMatch(url, "*/pagecount.gif*")
		|| shExpMatch(url, "*/adlog.pl*")
	       )
	   )

	// OfficeMax affiliate art
	|| (dnsDomainIs(host, ".officemax.com")
	    && shExpMatch(url, "*/affArt/*")
	)

/// matched by global rules
///	// shockwave & animated ads
///	|| shExpMatch(url, "*sharkyextreme.com/ads/*")
///	|| (dnsDomainIs(host,"anandtech.com")
///		&& shExpMatch(url,"*/banners/*"))

	// complicated JavaScript for directed ads!
	|| (dnsDomainIs(host, ".anandtech.com")
	    && shExpMatch(url,"*/js/*")
	)

	//////
	//
	// "Other Scum And Villainry"
	//

	// Popup from "reserved" domains at register.com
	// (I considered blocking all of register.com)
	|| (dnsDomainIs(host, ".register.com")
	    && (shExpMatch(url,"*.js")
		|| shExpMatch(host, "searchtheweb*")
		|| shExpMatch(host, "futuresite*")
	    )
	)

	|| dnsDomainIs(host, ".oingo.com")
	|| dnsDomainIs(host, ".namingsolutions.com")

	// "Data collection"
	|| dnsDomainIs(host, ".coremetrics.com")

	// Sets your home page
	|| dnsDomainIs(host, ".firehunt.com")

	// tracking
	|| dnsDomainIs(host, ".appliedsemantics.com")

	// Scum who buy ad space from the above
	// || dnsDomainIs(host, ".hartfordrents.com")
	// || dnsDomainIs(host, ".chicagocomputerrentals.com")
	// || dnsDomainIs(host, ".ccrsolutions.com")
	// || dnsDomainIs(host, ".rushcomputer.com")
	// || dnsDomainIs(host, ".localesimates.com")
	// || dnsDomainIs(host, ".unitedvision.com")
	|| isInNet(host, "216.216.246.31", "255.255.255.255")

	// bogus "search" sites at non-existent sites
	|| dnsDomainIs(host, ".search411.com")

	//////
	//
	// Contributed adult sites
	//

	|| dnsDomainIs(host, ".porntrack.com")
	|| dnsDomainIs(host, ".sexe-portail.com")
	|| dnsDomainIs(host, ".sextracker.com")
	|| dnsDomainIs(host, ".sexspy.com")
	|| dnsDomainIs(host, ".offshoreclicks.com")
	|| dnsDomainIs(host, ".exxxit.com")

	// debug
	// || (alertmatch("NOT:" + url) && 0)

	) {

	// alert("blackholing: " + url);

	// ***
	// *** Update the next line with the correct
	// *** hostname:port of your blackhole proxy server
	// ***

	return "PROXY localhost:3421";
    } else {
	// debug
	// alert("allowing: " + url);

	// all other requests go direct and avoid any overhead
	return "DIRECT";

	// ****
	// **** If you cannot go direct or need to use an actual proxy
	// **** (such as used by an ISP or business or on a firewall),
	// **** change the "DIRECT" above to "PROXY hostname:port",
	// **** with the correct hostname:port for your proxy server.
	// ****
    }
}

///////////////////////////////////////////////////////////////////////////////
//
// This line is just for testing; you can ignore it.  But, if you are having
// problems where you think this PAC file isn't being loaded, then change this
// to read "if (1)" and the alert box should appear when the browser loads this
// file.
//
// This works for IE4, IE5, IE5.5, IE6 and Netscape 2.x, 3.x, and 4.x.
// This does not work for Mozilla (and probably not for Netscape 6.x).
// (For IE6, tested on Win2K)
//
if (0) {
//	alert("autoconfig notice: LOADED");
}

// The above should show you that this JavaScript is executed in an
// unprotected global context.  NEVER point at someone elses autoconfig file;
// always load from your own copy!

// an alert that returns true
function alertmatch(url)
{
//	alert("match: "+url);
	return 1;
}

// "window.confirm" does not work.
// function confirmmatch(url)
// {
// 	if (window.confirm(url))
// 		return 0;
// 	else
// 		return 1;
// }


///////////////////////////////////////////////////////////////////////////////
//
// Tired of reading boring comments?  Try reading today's comics:
//	http://www.schooner.com/~loverso/comics/
//
// or getting a quote from my collection:
//	http://www.schooner.com/~loverso/quote/
//

// eof
